@@ -1,5 +1,5 @@
 // CALCIT VERSION
-export const calcit_version = "0.4.9";
+export const calcit_version = "0.4.10";
 
 import { overwriteComparator, initTernaryTreeMap } from "@calcit/ternary-tree";
 import { parse } from "@cirru/parser.ts";
@@ -681,7 +681,14 @@ export let round_$q_ = (a: number) => {
   return a == Math.round(a);
 };
 export let _$n_str_$o_concat = (a: string, b: string) => {
-  return `${toString(a, false)}${toString(b, false)}`;
+  let buffer = "";
+  if (a != null) {
+    buffer += toString(a, false);
+  }
+  if (b != null) {
+    buffer += toString(b, false);
+  }
+  return buffer;
 };
 export let sort = (xs: CalcitList, f: CalcitFn): CalcitList => {
   if (xs == null) {
@@ -1439,7 +1446,6 @@ export let _$n_list_$o_distinct = (xs: CalcitList): CalcitList => {
 
 // special procs have to be defined manually
 export let reduce = foldl;
-export let conj = append;
 
 let unavailableProc = (...xs: []) => {
   console.warn("NOT available for calcit-js");
